add_anomaly: Add an anomaly component to specification

View source: R/methods.R

add_anomalyR Documentation

Add an anomaly component to specification

Description

Generic method for identified anomaly component (such as outliers) of a model.

Usage

add_anomaly(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding an anomaly component to the specification, separate from the regressor components.

Value

The specification object with an anomaly component.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.