add_custom: Add a custom component to specification

View source: R/methods.R

add_customR Documentation

Add a custom component to specification

Description

Generic method for a custom component of a model.

Usage

add_custom(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding a custom component to the specification.

Value

The specification object with a custom component.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.