add_distribution: Add an error distribution component to specification

View source: R/methods.R

add_distributionR Documentation

Add an error distribution component to specification

Description

Generic method for the distribution component of a model.

Usage

add_distribution(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding a specific distribution component to the specification.

Value

The specification object with a distribution component.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.