add_holiday: Add a holiday component to specification

View source: R/methods.R

add_holidayR Documentation

Add a holiday component to specification

Description

Generic method for the holiday component of a model.

Usage

add_holiday(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding a holiday component to the specification.

Value

The specification object with a holiday component.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.