add_polynomial: Add a polynomial component to specification

View source: R/methods.R

add_polynomialR Documentation

Add a polynomial component to specification

Description

Generic method for the polynomial component of a model.

Usage

add_polynomial(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding a polyomial component to the specification.

Value

The specification object with a polynomial component.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.