add_regressor: Add a regressor component to specification

View source: R/methods.R

add_regressorR Documentation

Add a regressor component to specification

Description

Generic method for the regressor component of a model.

Usage

add_regressor(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding a regressor component to the specification.

Value

The specification object with a regressor component.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.