add_transform: Add a data transformation to specification

View source: R/methods.R

add_transformR Documentation

Add a data transformation to specification

Description

Generic method for a data transformation of a model.

Usage

add_transform(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Details

The method is used in state space estimation and simulation models for adding a data transformation to the specification.

Value

The specification object with a data transformation.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.