estimate_ad: Estimation method using AD

View source: R/methods.R

estimate_adR Documentation

Estimation method using AD

Description

Generic method for estimating a model using automatic differentiation. This may be deprecated in the future in favor of just using the estimate method.

Usage

estimate_ad(object, ...)

Arguments

object

an object.

...

additional parameters passed to the method.

Value

The estimated autodiff model.


tsmethods documentation built on Feb. 15, 2026, 9:06 a.m.