| add_anomaly | R Documentation |
Generic method for identified anomaly component (such as outliers) of a model.
add_anomaly(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding an anomaly component to the specification, separate from the regressor components.
The specification object with an anomaly component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.