| add_custom | R Documentation |
Generic method for a custom component of a model.
add_custom(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a custom component to the specification.
The specification object with a custom component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.