| add_distribution | R Documentation |
Generic method for the distribution component of a model.
add_distribution(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a specific distribution component to the specification.
The specification object with a distribution component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.