| add_holiday | R Documentation |
Generic method for the holiday component of a model.
add_holiday(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a holiday component to the specification.
The specification object with a holiday component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.