| add_polynomial | R Documentation |
Generic method for the polynomial component of a model.
add_polynomial(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a polyomial component to the specification.
The specification object with a polynomial component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.