| add_regressor | R Documentation |
Generic method for the regressor component of a model.
add_regressor(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a regressor component to the specification.
The specification object with a regressor component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.