| add_seasonal | R Documentation |
Generic method for the seasonal component of a model.
add_seasonal(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a seasonal component to the specification.
The specification object with a seasonal component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.