add_seasonal: Add a seasonal component to specification
Description
Generic method for the seasonal component of a model.
Usage
add_seasonal(object, ...)
Value
The specification object with a seasonal component.
Arguments
- object
an object.
- ...
additional parameters passed to the method.
Details
The method is used in state space estimation and simulation
models for adding a seasonal component to the specification.