| add_transform | R Documentation |
Generic method for a data transformation of a model.
add_transform(object, ...)
object |
an object. |
... |
additional parameters passed to the method. |
The method is used in state space estimation and simulation models for adding a data transformation to the specification.
The specification object with a data transformation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.